@@ -7,6 +7,7 @@ import heapq
 import queue
 from time import sleep
 
+
 class PriorityQueue:
     '''
     put() higher priority get() earlier. default priority is 5.
@@ -29,15 +30,18 @@ class PriorityQueue:
                 raise Exception("empty")
             return heapq.heappop(self._queue)[-1]
 
-def thread_test(sec):
-    print(f"start {sec}")
-    sleep(sec)
-    print(f"end {sec}")
+    def len(self, timeout=None):
+        return len(self._queue)
+
 
 if __name__ == '__main__':
     print("Mission start!")
-    for i in [20, 10, 5, 1]:
-        threading.Thread(target=thread_test, args=(i,)).start()
+    q = PriorityQueue()
+    q.put(7)
+    print(q.len())
+
+    print(q.get())
+    print(q.len())
 
     print("Mission complete!")
 
